@@ -1,3 +1,3 @@
-PROJECTNAME = "PloneSlimbos"
+PROJECTNAME = "PloneSlimbox"
 SKINNAME = "plone_slimbox"
 GLOBALS=globals()
